.. django-rest-email-auth documentation master file, created by
   sphinx-quickstart on Fri Nov  3 12:44:08 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

-------------------------------------------------------------------------------

.. toctree::
   :maxdepth: 2
   :caption: Contents

   installation
   configuration
   endpoints
   commands
   custom-serializers
   CHANGELOG



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
